<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

return [

	// D
	'dump_description' => 'Sauvagarda de la basa en SQLite e restauramen',
	'dump_slogan' => 'Sauvagarda e restauramen de la basa SPIP',
];
